==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QTableView_shell.h <==
#ifndef QTABLEVIEW_SHELL_H
#define QTABLEVIEW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(tableview)
#include <QtWidgets/qtableview.h>
#endif //QT_CONFIG(tableview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qheaderview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(tableview)

class QTableView_shell : public QTableView, public QtJambiShellInterface
{
public:
    QTableView_shell(QWidget* parent0 = nullptr);
    ~QTableView_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEditor(QWidget* editor0, QAbstractItemDelegate::EndEditHint hint1) override;
    void closeEvent(QCloseEvent* event0) override;
    void commitData(QWidget* editor0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    void currentChanged(const QModelIndex& current0, const QModelIndex& previous1) override;
    void customEvent(QEvent* event0) override;
    void dataChanged(const QModelIndex& topLeft0, const QModelIndex& bottomRight1, const QList<int>& roles2) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doItemsLayout() override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    bool edit(const QModelIndex& index0, QAbstractItemView::EditTrigger trigger1, QEvent* event2) override;
    void editorDestroyed(QObject* editor0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    int horizontalOffset() const override;
    void horizontalScrollbarAction(int action0) override;
    void horizontalScrollbarValueChanged(int value0) override;
    QModelIndex indexAt(const QPoint& p0) const override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void initViewItemOption(QStyleOptionViewItem* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isIndexHidden(const QModelIndex& index0) const override;
    QAbstractItemDelegate* itemDelegateForIndex(const QModelIndex& index0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void keyboardSearch(const QString& search0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction0, Qt::KeyboardModifiers modifiers1) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* e0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reset() override;
    void resizeEvent(QResizeEvent* event0) override;
    void rowsAboutToBeRemoved(const QModelIndex& parent0, int start1, int end2) override;
    void rowsInserted(const QModelIndex& parent0, int start1, int end2) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void scrollTo(const QModelIndex& index0, QAbstractItemView::ScrollHint hint1) override;
    void selectAll() override;
    QList<QModelIndex> selectedIndexes() const override;
    void selectionChanged(const QItemSelection& selected0, const QItemSelection& deselected1) override;
    QItemSelectionModel::SelectionFlags selectionCommand(const QModelIndex& index0, const QEvent* event1) const override;
    void setModel(QAbstractItemModel* model0) override;
    void setRootIndex(const QModelIndex& index0) override;
    void setSelection(const QRect& rect0, QItemSelectionModel::SelectionFlags command1) override;
    void setSelectionModel(QItemSelectionModel* selectionModel0) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    int sizeHintForColumn(int column0) const override;
    int sizeHintForRow(int row0) const override;
    void startDrag(Qt::DropActions supportedActions0) override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorData() override;
    void updateEditorGeometries() override;
    void updateGeometries() override;
    int verticalOffset() const override;
    void verticalScrollbarAction(int action0) override;
    void verticalScrollbarValueChanged(int value0) override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    QRect visualRect(const QModelIndex& index0) const override;
    QRegion visualRegionForSelection(const QItemSelection& selection0) const override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTableView_access : public QTableView
{
    void __qt_columnCountChanged_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint oldCount0, jint newCount1);
    void __qt_columnMoved_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint oldIndex1, jint newIndex2);
    void __qt_columnResized_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint oldWidth1, jint newWidth2);
    void __qt_rowCountChanged_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint oldCount0, jint newCount1);
    void __qt_rowMoved_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint oldIndex1, jint newIndex2);
    void __qt_rowResized_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint oldHeight1, jint newHeight2);
    void __qt_currentChanged_cref_QModelIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID current0, QtJambiNativeID previous1);
    void __qt_doItemsLayout(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_horizontalOffset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_horizontalScrollbarAction_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint action0);
    jobject __qt_indexAt_cref_QPoint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID p0) const;
    void __qt_initViewItemOption_QStyleOptionViewItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0) const;
    jboolean __qt_isIndexHidden_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_moveCursor_QAbstractItemView_CursorAction_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorAction0, jint modifiers1);
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_scrollTo_cref_QModelIndex_QAbstractItemView_ScrollHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint hint1);
    jobject __qt_selectedIndexes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_selectionChanged_cref_QItemSelection_cref_QItemSelection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selected0, QtJambiNativeID deselected1);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setRootIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0);
    void __qt_setSelection_cref_QRect_QItemSelectionModel_SelectionFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0, jint command1);
    void __qt_setSelectionModel_QItemSelectionModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selectionModel0);
    jint __qt_sizeHintForColumn_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0) const;
    jint __qt_sizeHintForRow_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_updateGeometries(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_verticalOffset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_verticalScrollbarAction_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint action0);
    jobject __qt_viewportSizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_visualRect_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_visualRegionForSelection_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selection0) const;
};

#endif // QT_CONFIG(tableview)
#endif // QTABLEVIEW_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QTableView_shell.h <==
#ifndef QTABLEVIEW_SHELL_H
#define QTABLEVIEW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(tableview)
#include <QtWidgets/qtableview.h>
#endif //QT_CONFIG(tableview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qheaderview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(tableview)

class QTableView_shell : public QTableView, public QtJambiShellInterface
{
public:
    QTableView_shell(QWidget* parent0 = nullptr);
    ~QTableView_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEditor(QWidget* editor0, QAbstractItemDelegate::EndEditHint hint1) override;
    void closeEvent(QCloseEvent* event0) override;
    void commitData(QWidget* editor0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    void currentChanged(const QModelIndex& current0, const QModelIndex& previous1) override;
    void customEvent(QEvent* event0) override;
    void dataChanged(const QModelIndex& topLeft0, const QModelIndex& bottomRight1, const QList<int>& roles2) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doItemsLayout() override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    bool edit(const QModelIndex& index0, QAbstractItemView::EditTrigger trigger1, QEvent* event2) override;
    void editorDestroyed(QObject* editor0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    int horizontalOffset() const override;
    void horizontalScrollbarAction(int action0) override;
    void horizontalScrollbarValueChanged(int value0) override;
    QModelIndex indexAt(const QPoint& p0) const override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void initViewItemOption(QStyleOptionViewItem* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isIndexHidden(const QModelIndex& index0) const override;
    QAbstractItemDelegate* itemDelegateForIndex(const QModelIndex& index0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void keyboardSearch(const QString& search0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction0, Qt::KeyboardModifiers modifiers1) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* e0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reset() override;
    void resizeEvent(QResizeEvent* event0) override;
    void rowsAboutToBeRemoved(const QModelIndex& parent0, int start1, int end2) override;
    void rowsInserted(const QModelIndex& parent0, int start1, int end2) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void scrollTo(const QModelIndex& index0, QAbstractItemView::ScrollHint hint1) override;
    void selectAll() override;
    QList<QModelIndex> selectedIndexes() const override;
    void selectionChanged(const QItemSelection& selected0, const QItemSelection& deselected1) override;
    QItemSelectionModel::SelectionFlags selectionCommand(const QModelIndex& index0, const QEvent* event1) const override;
    void setModel(QAbstractItemModel* model0) override;
    void setRootIndex(const QModelIndex& index0) override;
    void setSelection(const QRect& rect0, QItemSelectionModel::SelectionFlags command1) override;
    void setSelectionModel(QItemSelectionModel* selectionModel0) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    int sizeHintForColumn(int column0) const override;
    int sizeHintForRow(int row0) const override;
    void startDrag(Qt::DropActions supportedActions0) override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorData() override;
    void updateEditorGeometries() override;
    void updateGeometries() override;
    int verticalOffset() const override;
    void verticalScrollbarAction(int action0) override;
    void verticalScrollbarValueChanged(int value0) override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    QRect visualRect(const QModelIndex& index0) const override;
    QRegion visualRegionForSelection(const QItemSelection& selection0) const override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTableView_access : public QTableView
{
    void __qt_columnCountChanged_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint oldCount0, jint newCount1);
    void __qt_columnMoved_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint oldIndex1, jint newIndex2);
    void __qt_columnResized_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint oldWidth1, jint newWidth2);
    void __qt_rowCountChanged_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint oldCount0, jint newCount1);
    void __qt_rowMoved_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint oldIndex1, jint newIndex2);
    void __qt_rowResized_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint oldHeight1, jint newHeight2);
    void __qt_currentChanged_cref_QModelIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID current0, QtJambiNativeID previous1);
    void __qt_doItemsLayout(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_horizontalOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_horizontalScrollbarAction_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint action0);
    jobject __qt_indexAt_cref_QPoint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID p0) const;
    void __qt_initViewItemOption_QStyleOptionViewItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0) const;
    jboolean __qt_isIndexHidden_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_moveCursor_QAbstractItemView_CursorAction_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorAction0, jint modifiers1);
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_scrollTo_cref_QModelIndex_QAbstractItemView_ScrollHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint hint1);
    jobject __qt_selectedIndexes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_selectionChanged_cref_QItemSelection_cref_QItemSelection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selected0, QtJambiNativeID deselected1);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setRootIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0);
    void __qt_setSelection_cref_QRect_QItemSelectionModel_SelectionFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0, jint command1);
    void __qt_setSelectionModel_QItemSelectionModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selectionModel0);
    jint __qt_sizeHintForColumn_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0) const;
    jint __qt_sizeHintForRow_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_updateGeometries(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_verticalOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_verticalScrollbarAction_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint action0);
    jobject __qt_viewportSizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_visualRect_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_visualRegionForSelection_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selection0) const;
};

#endif // QT_CONFIG(tableview)
#endif // QTABLEVIEW_SHELL_H
